@@ -1,6 +1,7 @@
 from .chat import ChatManager
 from .api import API
 from functools import wraps
+import asyncio
 
 
 class HyperChat:
@@ -15,6 +16,11 @@ class HyperChat:
 
     def run(self):
         self.chat_manager = ChatManager(self, self.host, self.token, self.api.lista_canales(), ssl_active=self.ssl)
+        loop = asyncio.get_event_loop()
+        try:
+            loop.run_forever()
+        finally:
+            loop.close()
 
     def handler(self, commands: list):
         def decorator(f):
